@@ -1,9 +1,7 @@
 """Integration tests for Cloudflare"""
 from unittest import TestCase
 
-import pytest
 from lexicon.tests.providers.integration_tests import IntegrationTests
-from lexicon.providers.cloudflare import Provider
 
 
 # Hook into testing framework by inheriting unittest.TestCase and reuse
@@ -11,13 +9,16 @@ from lexicon.providers.cloudflare import Provider
 # pass, by inheritance from define_tests.TheTests
 class CloudflareProviderTests(TestCase, IntegrationTests):
     """TestCase for Cloudflare"""
-    Provider = Provider
     provider_name = 'cloudflare'
-    domain = 'capsulecd.com'
+    domain = 'pacalis.net'
 
     def _filter_headers(self):
         return ['X-Auth-Email', 'X-Auth-Key', 'set-cookie']
 
-    @pytest.mark.skip(reason="new test, missing recording")
-    def test_provider_when_calling_update_record_should_modify_record_name_specified(self):
-        return
+    # We do not want to have "placeholder_auth_username" as default value for `--auth-username`
+    # if Bearer tokens are used to execute the tests, because the non-emptiness of this flags
+    # triggers interpretation of `--auth-key` as a Global API key.
+    # Similarly for `--zone-id`, we want to control when its value is not empty, because
+    # it will change the logic of the authentication process.
+    def _test_fallback_fn(self):
+        return lambda x: 'placeholder_' + x if x not in ('auth_username', 'zone_id') else ''
